import { Suspense } from "react";

import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Statistics from "@/components/sections/home/statistics";
import { AboutProjectClient } from "@/components/sections/projects/about-projects";
import Ads from "@/components/sections/projects/ads";
import { ProjectTestimonialSectionClient } from "@/components/sections/projects/project-testimonial";
import { PageBreadcrumb } from "@/components/shared/page-breadcrump";
import { ImageBaseUrl } from "@/configs/api";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchProjects } from "@/servers/actions/project-action";
import type { LocaleParams } from "@/types/params";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";

export default async function ProjectsPage({
	params,
}: {
	params: LocaleParams;
}) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/projects",
			label: {
				en: "Projects",
				ar: "المشاريع",
			},
		},
	];


	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["projects"], queryFn: fetchProjects }),

	]);

	const _data = queryClient.getQueryData<any>(["basicInfo"]);

	const _projects = _data?.data?.pages_headers?.find((val: any) => val.page == "projects");


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="min-h-screen">
				<Header />
				<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
					<PageBreadcrumb
						backgroundImage={ImageBaseUrl + _projects?.page_image}
						subtitle={{
							en: _projects?.text?.en,
							ar: _projects?.text?.ar,
						}}
						title={{
							en: _projects?.description?.en,
							ar: _projects?.description?.ar,
						}}
						breadcrumbItems={breadcrumbItems}
						locale={locale}
					/>
					<AboutProjectClient />
					<ProjectTestimonialSectionClient />
					<Statistics />
					<Ads />
					<Footer />
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}
